
# TODO:
#	- test__core_stat.py fails on 32-bit builds with system libev
#	  investigate/fix that and enable system libev
#
#	- investigate some other failing tests
#	  (now excluded via known_failures-pld.patch)

# Conditional build:
%bcond_without	tests		# do not run tests
%bcond_with	system_libev	# build with system libev [test__core_stat.py test fails]
%bcond_without	system_c_ares	# build with system c_ares
%bcond_without	python2		# CPython 2.x module
%bcond_without	python3		# CPython 3.x module

%define	module	gevent
Summary:	A coroutine-based Python 2 networking library
Summary(pl.UTF-8):	Biblioteka sieciowa dla Pythona 2 oparta na korutynach
Name:		python-%{module}
Version:	1.3.7
Release:	1
Epoch:		1
License:	MIT
Group:		Development/Languages
#Source0Download: https://pypi.python.org/simple/gevent
Source0:	https://files.pythonhosted.org/packages/source/g/gevent/%{module}-%{version}.tar.gz
# Source0-md5:	5d3f61ef4bb40fdbd5cbaac7f0d2e585
Patch0:		known_failures-pld.patch
Patch1:		%{name}-tests.patch
URL:		http://www.gevent.org/
%{?with_system_c_ares:BuildRequires:	c-ares-devel >= 1.10.0}
%{?with_system_libev:BuildRequires:	libev-devel >= 4.23}
BuildRequires:	python-Cython >= 0.28.5
%if %{with python2}
BuildRequires:	python-cffi >= 1.3.0
BuildRequires:	python-devel >= 1:2.7
BuildRequires:	python-greenlet-devel >= 0.4.15
%if %{with tests}
BuildRequires:	python-coverage >= 4.0
BuildRequires:	python-devel-src >= 1:2.7
BuildRequires:	python-greenlet >= 0.4.15
BuildRequires:  python-objgraph
BuildRequires:	python-setuptools
BuildRequires:	python-test
%endif
%endif
%if %{with python3}
BuildRequires:	python3-cffi >= 1.3.0
BuildRequires:	python3-devel >= 1:3.3
BuildRequires:	python3-greenlet-devel >= 0.4.15
%if %{with tests}
BuildRequires:	python3-coverage >= 4.0
BuildRequires:	python3-greenlet >= 0.4.10
BuildRequires:  python3-objgraph
BuildRequires:	python3-setuptools
BuildRequires:	python3-test
%endif
%endif
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
%{?with_system_libev:Requires:	libev >= 4.23}
Requires:	python-greenlet >= 0.4.15
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
gevent is a coroutine-based Python networking library. Features
include:
- Fast event loop based on libev.
- Lightweight execution units based on greenlet.
- Familiar API that re-uses concepts from the Python standard library.
- Cooperative sockets with SSL support.
- DNS queries performed through c-ares or a threadpool.
- Ability to use standard library and 3rd party modules written for
  standard blocking sockets.

%description -l pl.UTF-8
gevent to biblioteka sieciowa dla Pythona oparta na korutynach. Jej
możliwości to m.in.
- szybka pętla zdarzeń oparta na libev
- lekkie jednostki wykonywania oparte na bibliotece greenlet
- znajome API wykorzystujące koncepty biblioteki standardowej Pythona
- gniazda kooperatywne z obsługą SSL
- zapytania DNS wykonywane przez bibliotekę c-ares lub pulę wątków
- możliwość wykorzystania biblioteki standardowej lub modułów innych
  producentów napisanych dla standardowych gniazd blokujących

%package -n python3-%{module}
Summary:	A coroutine-based Python 3 networking library
Summary(pl.UTF-8):	Biblioteka sieciowa dla Pythona 3 oparta na korutynach
Group:		Libraries/Python
%{?with_system_libev:Requires:	libev >= 4.23}
Requires:	python-greenlet >= 0.4.15

%description -n python3-%{module}
gevent is a coroutine-based Python networking library. Features
include:
- Fast event loop based on libev.
- Lightweight execution units based on greenlet.
- Familiar API that re-uses concepts from the Python standard library.
- Cooperative sockets with SSL support.
- DNS queries performed through c-ares or a threadpool.
- Ability to use standard library and 3rd party modules written for
  standard blocking sockets

%description -n python3-%{module} -l pl.UTF-8
gevent to biblioteka sieciowa dla Pythona oparta na korutynach. Jej
możliwości to m.in.
- szybka pętla zdarzeń oparta na libev
- lekkie jednostki wykonywania oparte na bibliotece greenlet
- znajome API wykorzystujące koncepty biblioteki standardowej Pythona
- gniazda kooperatywne z obsługą SSL
- zapytania DNS wykonywane przez bibliotekę c-ares lub pulę wątków
- możliwość wykorzystania biblioteki standardowej lub modułów innych
  producentów napisanych dla standardowych gniazd blokujących

%prep
%setup -q -n %{module}-%{version}
%patch0 -p1
%patch1 -p1 -b .orig

%build

# force rebuild of Cython-generated files
# they depend on specific deps (e.g. greenlet) versions
rm src/gevent/{*.c,resolver/cares.c}

# must be exported to work (py*_build macro is not single invocation)
%{?with_system_libev:export LIBEV_EMBED=false}
%{?with_system_c_ares:export CARES_EMBED=false}

%if %{with python2}
%py_build

%if %{with tests}
PKGDIR=$(echo $PWD/build-2/lib.*)
cd src/greentest
PYTHONPATH=$PKGDIR %{__python} testrunner.py --config known_failures.py
cd ../..
%endif
%endif

%if %{with python3}
%py3_build

%if %{with tests}
PKGDIR=$(echo $PWD/build-3/lib.*)
cd src/greentest
PYTHONPATH=$PKGDIR %{__python3} testrunner.py --config known_failures.py
cd ../..
%endif
%endif

%install
rm -rf $RPM_BUILD_ROOT

%{?with_system_libev:export LIBEV_EMBED=false}
%{?with_system_c_ares:export CARES_EMBED=false}

%if %{with python2}
%py_install

%py_postclean
%{__rm} $RPM_BUILD_ROOT%{py_sitedir}/gevent/*.c
%{__rm} $RPM_BUILD_ROOT%{py_sitedir}/gevent/*/*.{c,h,pyx}
%endif

%if %{with python3}
%py3_install

%{__rm} $RPM_BUILD_ROOT%{py3_sitedir}/gevent/*.c
%{__rm} $RPM_BUILD_ROOT%{py3_sitedir}/gevent/*/*.{c,h,pyx}
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%files
%defattr(644,root,root,755)
%doc AUTHORS LICENSE NOTICE README.rst TODO
%dir %{py_sitedir}/gevent
%attr(755,root,root) %{py_sitedir}/gevent/*.so
%{py_sitedir}/gevent/*.pxd
%{py_sitedir}/gevent/*.py[co]
%dir %{py_sitedir}/gevent/_ffi
%{py_sitedir}/gevent/_ffi/*.py[co]
%dir %{py_sitedir}/gevent/libev
%attr(755,root,root) %{py_sitedir}/gevent/libev/_corecffi.so
%attr(755,root,root) %{py_sitedir}/gevent/libev/corecext.so
%{py_sitedir}/gevent/libev/libev.pxd
%{py_sitedir}/gevent/libev/*.py[co]
%dir %{py_sitedir}/gevent/libuv
%{py_sitedir}/gevent/libuv/*.py[co]
%attr(755,root,root) %{py_sitedir}/gevent/libuv/_corecffi.so
%dir %{py_sitedir}/gevent/resolver
%{py_sitedir}/gevent/resolver/libcares.pxd
%{py_sitedir}/gevent/resolver/*.py[co]
%attr(755,root,root) %{py_sitedir}/gevent/resolver/cares.so
%{py_sitedir}/gevent-%{version}-py%{py_ver}.egg-info
%endif

%if %{with python3}
%files -n python3-%{module}
%defattr(644,root,root,755)
%doc AUTHORS LICENSE NOTICE README.rst TODO
%dir %{py3_sitedir}/gevent
%attr(755,root,root) %{py3_sitedir}/gevent/*.cpython-*.so
%{py3_sitedir}/gevent/__pycache__
%{py3_sitedir}/gevent/*.pxd
%{py3_sitedir}/gevent/*.py
%dir %{py3_sitedir}/gevent/_ffi
%{py3_sitedir}/gevent/_ffi/__pycache__
%{py3_sitedir}/gevent/_ffi/*.py
%dir %{py3_sitedir}/gevent/libuv
%{py3_sitedir}/gevent/libuv/__pycache__
%{py3_sitedir}/gevent/libuv/*.py
%attr(755,root,root) %{py3_sitedir}/gevent/libuv/_corecffi.*.so
%dir %{py3_sitedir}/gevent/libev
%attr(755,root,root) %{py3_sitedir}/gevent/libev/_corecffi.abi3.so
%attr(755,root,root) %{py3_sitedir}/gevent/libev/corecext.cpython-*.so
%{py3_sitedir}/gevent/libev/__pycache__
%{py3_sitedir}/gevent/libev/libev.pxd
%{py3_sitedir}/gevent/libev/*.py
%dir %{py3_sitedir}/gevent/resolver
%{py3_sitedir}/gevent/resolver/__pycache__
%{py3_sitedir}/gevent/resolver/*.py
%{py3_sitedir}/gevent/resolver/libcares.pxd
%attr(755,root,root) %{py3_sitedir}/gevent/resolver/cares.*.so
%{py3_sitedir}/gevent-%{version}-py*.egg-info
%endif
%changelog
* Mon Oct 22 2018 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python-gevent.git;a=log;h=master

* Mon Oct 22 2018 Jacek Konieczny <j.konieczny@eggsoft.pl> a412afa
- Version: 1.3.7, force rebuild and deps

* Mon Jul 02 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> cf0d448
- up to 1.3.4

* Sun Jul 01 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 1ef5cee
- release 3 (by relup.sh)

* Mon Mar 05 2018 Jacek Konieczny <j.konieczny@eggsoft.pl> 17db316
- more test failing due to missing network

* Mon Mar 05 2018 Jacek Konieczny <j.konieczny@eggsoft.pl> b845a2a
- Version: 1.2.2

* Mon Apr 17 2017 Jakub Bogusz <qboosh@pld-linux.org> e2766a9
- don't hardcode python version in files

* Sun Apr 16 2017 Jan Rękorajski <baggins@pld-linux.org> 3b06763
- fix files more
- rel 3

* Sun Apr 16 2017 Jan Rękorajski <baggins@pld-linux.org> 084e700
- fix files
- rel 2

* Sun Apr 16 2017 Jan Rękorajski <baggins@pld-linux.org> 25ec343
- disable flaky test when run with python3
- updated python3 files

* Thu Mar 16 2017 Jakub Bogusz <qboosh@pld-linux.org> 4f53d0c
- updated to 1.2.1
- adjusted known_failures_pld patch (disable also socket_dns6 test)
- added tests patch (fix test with newer coreutils, avoid failure on python3.6)

* Wed Dec 28 2016 Arkadiusz Miśkiewicz <arekm@maven.pl> 079b59a
- python 3.6
- release 2 (by relup.sh)

* Mon Mar 14 2016 Jacek Konieczny <j.konieczny@eggsoft.pl> 966035b
- disable two more tests on builders

* Mon Mar 14 2016 Jacek Konieczny <j.konieczny@eggsoft.pl> 4fc6ecf
- Version: 1.1.0

* Sun Nov 29 2015 Jacek Konieczny <jajcus@jajcus.net> cc06e72
- BR: rpmbuild(macros) >= 1.710

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> 0af4ec6
- release 2 (by relup.sh)

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> 37c131a
- automatic change: use py_build/py_install macros

* Thu Oct 08 2015 Jacek Konieczny <j.konieczny@eggsoft.pl> 332badf
- Version: 1.1b5

* Tue Sep 15 2015 Jacek Konieczny <j.konieczny@eggsoft.pl> 725888f
- Version: 1.1b4

* Tue Sep 15 2015 Jacek Konieczny <j.konieczny@eggsoft.pl> bdf2025
- Test config patch from DEVEL branch

* Fri Aug 14 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 06c1ffe
- up to 1.1b2 (which is beta but support python3; introduce python3 packages)

